package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.CpsGlbMsg;

/**
 * cps_glb_msg 全局消息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-14
 */
public interface CpsGlbMsgMapper 
{
    /**
     * 查询cps_glb_msg 全局消息
     * 
     * @param id cps_glb_msg 全局消息主键
     * @return cps_glb_msg 全局消息
     */
    public CpsGlbMsg selectCpsGlbMsgById(Long id);

    /**
     * 查询cps_glb_msg 全局消息列表
     * 
     * @param cpsGlbMsg cps_glb_msg 全局消息
     * @return cps_glb_msg 全局消息集合
     */
    public List<CpsGlbMsg> selectCpsGlbMsgList(CpsGlbMsg cpsGlbMsg);

    /**
     * 新增cps_glb_msg 全局消息
     * 
     * @param cpsGlbMsg cps_glb_msg 全局消息
     * @return 结果
     */
    public int insertCpsGlbMsg(CpsGlbMsg cpsGlbMsg);

    /**
     * 修改cps_glb_msg 全局消息
     * 
     * @param cpsGlbMsg cps_glb_msg 全局消息
     * @return 结果
     */
    public int updateCpsGlbMsg(CpsGlbMsg cpsGlbMsg);

    /**
     * 删除cps_glb_msg 全局消息
     * 
     * @param id cps_glb_msg 全局消息主键
     * @return 结果
     */
    public int deleteCpsGlbMsgById(Long id);

    /**
     * 批量删除cps_glb_msg 全局消息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCpsGlbMsgByIds(Long[] ids);
}
